searchData={"items":[{"type":"module","title":"LEB128","doc":"Module for encoding and decoding LEB128 (Little Endian Base 128) encoded numbers.\nReference: https://en.wikipedia.org/wiki/LEB128#Unsigned_LEB128","ref":"LEB128.html"},{"type":"module","title":"Usage - LEB128","doc":"```elixir\niex> LEB128.encode_unsigned(624_485)\n<<0xE5, 0x8E, 0x26>>\n\niex> LEB128.decode_unsigned!(<<0xE5, 0x8E, 0x26>>)\n{624_485, \"\"}\n\niex> LEB128.decode_unsigned!(<<0xE5, 0x8E>>)\n{:error, :incomplete}\n```","ref":"LEB128.html#module-usage"},{"type":"function","title":"LEB128.decode_signed/1","doc":"Decodes a signed LEB128 encoded number.\n\nExample:\n```elixir\niex> LEB128.decode_signed(<<0xC0, 0xBB, 0x78>>)\n{:ok, -123_456, \"\"}\niex> LEB128.decode_signed(<<0xE5, 0x8E>>)\n{:error, :incomplete}\n```","ref":"LEB128.html#decode_signed/1"},{"type":"function","title":"LEB128.decode_signed!/1","doc":"Decodes a signed LEB128 encoded number. Crashes if the input is invalid.\n\nExample:\n```elixir\niex> LEB128.decode_signed!(<<0xC0, 0xBB, 0x78>>)\n{-123_456, \"\"}\n```","ref":"LEB128.html#decode_signed!/1"},{"type":"function","title":"LEB128.decode_unsigned/1","doc":"Decodes an unsigned LEB128 encoded number.\n\nExample:\n```elixir\niex> LEB128.decode_unsigned(<<0xE5, 0x8E, 0x26>>)\n{:ok, 624_485, \"\"}\niex> LEB128.decode_unsigned(<<0xE5, 0x8E>>)\n{:error, :incomplete}\n```","ref":"LEB128.html#decode_unsigned/1"},{"type":"function","title":"LEB128.decode_unsigned!/1","doc":"Decodes an unsigned LEB128 encoded number. Crashes if the input is invalid.\n\nExample:\n```elixir\niex> LEB128.decode_unsigned!(<<0xE5, 0x8E, 0x26>>)\n{624_485, \"\"}\n```","ref":"LEB128.html#decode_unsigned!/1"},{"type":"function","title":"LEB128.encode_signed/1","doc":"Encodes a signed LEB128 encoded number.\n\nExample:\n```elixir\niex> LEB128.encode_signed(-123_456)\n<<0xC0, 0xBB, 0x78>>\n```","ref":"LEB128.html#encode_signed/1"},{"type":"function","title":"LEB128.encode_unsigned/1","doc":"Encodes an unsigned LEB128 encoded number.\n\nExample:\n```elixir\niex> LEB128.encode_unsigned(624_485)\n<<0xE5, 0x8E, 0x26>>\n```","ref":"LEB128.html#encode_unsigned/1"},{"type":"extras","title":"LEB128","doc":"# LEB128\n\nLEB128 is a library for encoding and decoding LEB128 encoded numbers. LEB128 is a variable-length encoding for integers that is used in the WebAssembly binary format.\n\nhttps://en.wikipedia.org/wiki/LEB128","ref":"readme.html"},{"type":"extras","title":"Installation - LEB128","doc":"The package can be installed by adding `leb128` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:leb128, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - LEB128","doc":"```elixir\niex> LEB128.encode_unsigned(624_485)\n<<0xE5, 0x8E, 0x26>>\n\niex> LEB128.decode_unsigned!(<<0xE5, 0x8E, 0x26>>)\n{624_485, \"\"}\n\niex> LEB128.decode_unsigned!(<<0xE5, 0x8E>>)\n{:error, :incomplete}\n```","ref":"readme.html#usage"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}